
Building an AEA step by step:
<ol>
<li>Set up your AEA project.</li>
<li>Add the right <a href="../connection/">connections</a> for your usecase.</li>
<li>Add or code the <a href="../protocol/">protocols</a> you require.</li>
<li>Add or code the <a href="../skill/">skills</a> you need. <a href="../skill-guide/">This guide</a> shows you step by step how to develop a skill.</li>
<li>Where required, scaffold any of the above resources with the <a href="../scaffolding/">scaffolding tool</a> or generate a protocol with the <a href="../generator/">protocol generator</a>.</li>
<li>Now, run your AEA.</li> 
</ol>